@@ -445,7 +445,7 @@ class water:
         def __init__(self,input_bands):
             self.input_bands = input_bands   
             bands = dict()
-            for i,j in bands3.items():
+            for i,j in self.input_bands.items():
                 quantize = j.squeeze()/10000
                 bands.update({i:quantize})
             self.bands=bands
